@@ -1,4 +1,4 @@
-import classes
+from cassavapy import FileX, Experimental, Seasonal
 import unittest
 from datetime import date
 import numpy as np
@@ -10,16 +10,19 @@ class Test_basic_FileX_phf(unittest.TestCase):
         design "phf", sem irrigação'''
 
     def setUp(self):
-        self.filex = classes.FileX("cruz", "CRUZ9101", "phf")
+            
+        self.filex = FileX("cruz", "CRUZ9101", "phf")
         self.filex.p_from = date.fromisoformat('1992-12-30')
-
+    
         self.filex.set_planting(n_plant=3,
                                 p_from='1992-12-30',
                                 p_by=25)
 
         self.filex.set_harvest(n_harvest=3,
-                               h_from='1993-01-01',
-                               h_by=60)
+                                h_from='1993-01-01',
+                                h_by=60)
+
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
 
     def test_planting(self):
         expected = ["92365", "93024", "93049"]
@@ -48,7 +51,7 @@ class Test_basic_FileX_NULL(unittest.TestCase):
 
     def setUp(self):
 
-        self.filex = classes.FileX("cruz", "CRUZ9101")
+        self.filex = FileX("cruz", "CRUZ9101")
         self.filex.p_from = date.fromisoformat('1992-12-30')
 
         self.filex.set_planting(n_plant=4,
@@ -59,6 +62,8 @@ class Test_basic_FileX_NULL(unittest.TestCase):
                                h_from='1993-01-01',
                                h_by=60)
 
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
+
     def test_tratmatrix(self):
         self.filex.set_tratmatrix("BA")
 
@@ -87,7 +92,7 @@ class Test_basic_FileX_phf_irf(unittest.TestCase):
        '''
 
     def setUp(self):
-        self.filex = classes.FileX("cruz", "CRUZ9101", ["phf", "irf"])
+        self.filex = FileX("cruz", "CRUZ9101", ["phf", "irf"])
 
         self.filex.set_planting(n_plant=3,
                                 p_from='1992-12-30',
@@ -97,6 +102,8 @@ class Test_basic_FileX_phf_irf(unittest.TestCase):
                                h_from='1993-01-01',
                                h_by=60)
 
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
+
     def test_irrigation_one_lamina(self):
 
         self.filex.set_irrigation(n_irrig=5,
@@ -247,7 +254,7 @@ class Test_basic_FileX_irf(unittest.TestCase):
        '''
 
     def setUp(self):
-        self.filex = classes.FileX("cruz", "CRUZ9101", ["irf"])
+        self.filex = FileX("cruz", "CRUZ9101", ["irf"])
 
         self.filex.set_planting(n_plant=2,
                                 p_from='1992-12-30',
@@ -257,6 +264,8 @@ class Test_basic_FileX_irf(unittest.TestCase):
                                h_from='1993-01-01',
                                h_by=60)
 
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
+
 
     def test_irrigation_one_lamina_irf(self):
 
@@ -330,7 +339,7 @@ class Test_basic_FileX_phf_irnf(unittest.TestCase):
        '''
 
     def setUp(self):
-        self.filex = classes.FileX("cruz", "CRUZ9101", ["phf", "irnf"])
+        self.filex = FileX("cruz", "CRUZ9101", ["phf", "irnf"])
 
         self.filex.set_planting(n_plant=3,
                                 p_from='1992-12-30',
@@ -340,6 +349,8 @@ class Test_basic_FileX_phf_irnf(unittest.TestCase):
                                h_from='1993-01-01',
                                h_by=60)
 
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
+
         self.reg = [[0, 5, 10, 15, 20, 25, 30],
                     [0, 10, 20, 30, 40],
                     [10, 20, 30, 40, 50, 60]]
@@ -454,7 +465,7 @@ class Test_basic_FileX_irnf_no_phf(unittest.TestCase):
 
        '''
     def setUp(self):
-        self.filex = classes.FileX("cruz", "CRUZ9101", ["irnf"])
+        self.filex = FileX("cruz", "CRUZ9101", ["irnf"])
 
         self.filex.set_planting(n_plant=3,
                                     p_from='1992-12-30',
@@ -464,6 +475,8 @@ class Test_basic_FileX_irnf_no_phf(unittest.TestCase):
                                    h_from='1993-01-01',
                                    h_by=60)
 
+        self.filex.set_genotype([("UC0002", "MCol-1684")])
+
         self.reg = [[0, 5, 10, 15, 20, 25, 30],
                     [0, 10, 20, 30, 40],
                     [10, 20, 30, 40, 50, 60]]
@@ -484,9 +497,7 @@ class Test_basic_FileX_irnf_no_phf(unittest.TestCase):
                                   laminas=[11, 22, 33],
                                   trat_irrig={1: 3, 2: 1, 3: 2})
 
-        expected = {1: [3],
-                        2: [1],
-                        3: [2]}
+        expected = {1: [3], 2: [1], 3: [2]}
 
         np.testing.assert_equal(self.filex._trat_irrig, expected)
 
